@@ -160,7 +160,6 @@ export function parse(str: string, options: ParseOptions = {}): Token[] {
   const consumeText = (): string => {
     let result = "";
     let value: string | undefined;
-    // tslint:disable-next-line
     while ((value = tryConsume("CHAR") || tryConsume("ESCAPED_CHAR"))) {
       result += value;
     }
@@ -190,7 +189,7 @@ export function parse(str: string, options: ParseOptions = {}): Token[] {
         prefix,
         suffix: "",
         pattern: pattern || defaultPattern,
-        modifier: tryConsume("MODIFIER") || ""
+        modifier: tryConsume("MODIFIER") || "",
       });
       continue;
     }
@@ -220,7 +219,7 @@ export function parse(str: string, options: ParseOptions = {}): Token[] {
         pattern: name && !pattern ? defaultPattern : pattern,
         prefix,
         suffix,
-        modifier: tryConsume("MODIFIER") || ""
+        modifier: tryConsume("MODIFIER") || "",
       });
       continue;
     }
@@ -269,7 +268,7 @@ export function tokensToFunction<P extends object = object>(
   const { encode = (x: string) => x, validate = true } = options;
 
   // Compile all the tokens into regexps.
-  const matches = tokens.map(token => {
+  const matches = tokens.map((token) => {
     if (typeof token === "object") {
       return new RegExp(`^(?:${token.pattern})$`, reFlags);
     }
@@ -391,7 +390,7 @@ export function regexpToFunction<P extends object = object>(
 ): MatchFunction<P> {
   const { decode = (x: string) => x } = options;
 
-  return function(pathname: string) {
+  return function (pathname: string) {
     const m = re.exec(pathname);
     if (!m) return false;
 
@@ -399,13 +398,12 @@ export function regexpToFunction<P extends object = object>(
     const params = Object.create(null);
 
     for (let i = 1; i < m.length; i++) {
-      // tslint:disable-next-line
       if (m[i] === undefined) continue;
 
       const key = keys[i - 1];
 
       if (key.modifier === "*" || key.modifier === "+") {
-        params[key.name] = m[i].split(key.prefix + key.suffix).map(value => {
+        params[key.name] = m[i].split(key.prefix + key.suffix).map((value) => {
           return decode(value, key);
         });
       } else {
@@ -464,7 +462,7 @@ function regexpToRegexp(path: RegExp, keys?: Key[]): RegExp {
       prefix: "",
       suffix: "",
       modifier: "",
-      pattern: ""
+      pattern: "",
     });
     execResult = groupsRegex.exec(path.source);
   }
@@ -480,7 +478,7 @@ function arrayToRegexp(
   keys?: Key[],
   options?: TokensToRegexpOptions & ParseOptions
 ): RegExp {
-  const parts = paths.map(path => pathToRegexp(path, keys, options).source);
+  const parts = paths.map((path) => pathToRegexp(path, keys, options).source);
   return new RegExp(`(?:${parts.join("|")})`, flags(options));
 }
 
@@ -538,10 +536,12 @@ export function tokensToRegexp(
     strict = false,
     start = true,
     end = true,
-    encode = (x: string) => x
+    encode = (x: string) => x,
+    delimiter = "/#?",
+    endsWith = "",
   } = options;
-  const endsWith = `[${escapeString(options.endsWith || "")}]|$`;
-  const delimiter = `[${escapeString(options.delimiter || "/#?")}]`;
+  const endsWithRe = `[${escapeString(endsWith)}]|$`;
+  const delimiterRe = `[${escapeString(delimiter)}]`;
   let route = start ? "^" : "";
 
   // Iterate over the tokens and create our regexp string.
@@ -563,7 +563,11 @@ export function tokensToRegexp(
             route += `(?:${prefix}(${token.pattern})${suffix})${token.modifier}`;
           }
         } else {
-          route += `(${token.pattern})${token.modifier}`;
+          if (token.modifier === "+" || token.modifier === "*") {
+            route += `((?:${token.pattern})${token.modifier})`;
+          } else {
+            route += `(${token.pattern})${token.modifier}`;
+          }
         }
       } else {
         route += `(?:${prefix}${suffix})${token.modifier}`;
@@ -572,23 +576,22 @@ export function tokensToRegexp(
   }
 
   if (end) {
-    if (!strict) route += `${delimiter}?`;
+    if (!strict) route += `${delimiterRe}?`;
 
-    route += !options.endsWith ? "$" : `(?=${endsWith})`;
+    route += !options.endsWith ? "$" : `(?=${endsWithRe})`;
   } else {
     const endToken = tokens[tokens.length - 1];
     const isEndDelimited =
       typeof endToken === "string"
-        ? delimiter.indexOf(endToken[endToken.length - 1]) > -1
-        : // tslint:disable-next-line
-          endToken === undefined;
+        ? delimiterRe.indexOf(endToken[endToken.length - 1]) > -1
+        : endToken === undefined;
 
     if (!strict) {
-      route += `(?:${delimiter}(?=${endsWith}))?`;
+      route += `(?:${delimiterRe}(?=${endsWithRe}))?`;
     }
 
     if (!isEndDelimited) {
-      route += `(?=${delimiter}|${endsWith})`;
+      route += `(?=${delimiterRe}|${endsWithRe})`;
     }
   }
 
